SecretStreamCipherMessage class sealed
A container class for a extended cipher message before decryption.
- Available extensions
- Annotations
-
- @freezed
Constructors
- SecretStreamCipherMessage(Uint8List message, {Uint8List? additionalData})
-
Default constructor
constfactory
Properties
- additionalData → Uint8List?
-
Additional data, that should be used to generate authentication data.
no setterinherited
-
copyWith
→ $SecretStreamCipherMessageCopyWith<
SecretStreamCipherMessage> -
Create a copy of SecretStreamCipherMessage
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → Uint8List
-
The message that should be decrypted.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_SecretStreamCipherMessage value)) → TResult -
Available on SecretStreamCipherMessage, provided by the SecretStreamCipherMessagePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_SecretStreamCipherMessage value)?) → TResult? -
Available on SecretStreamCipherMessage, provided by the SecretStreamCipherMessagePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_SecretStreamCipherMessage value)?, {required TResult orElse()}) → TResult -
Available on SecretStreamCipherMessage, provided by the SecretStreamCipherMessagePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(Uint8List message, Uint8List? additionalData)?, {required TResult orElse()}) → TResult -
Available on SecretStreamCipherMessage, provided by the SecretStreamCipherMessagePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(Uint8List message, Uint8List? additionalData)) → TResult -
Available on SecretStreamCipherMessage, provided by the SecretStreamCipherMessagePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(Uint8List message, Uint8List? additionalData)?) → TResult? -
Available on SecretStreamCipherMessage, provided by the SecretStreamCipherMessagePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited