verifyStream abstract method
Validate the signature from an aynchronous stream of data.
This is a shortcut for createVerifyConsumer, which simply calls
Stream.pipe on the messages stream and pipes it into the consumer. The
returned result is whether the signature over all the data in the
messages stream is correct, based on publicKey.
See https://libsodium.gitbook.io/doc/public-key_cryptography/public-key_signatures#multi-part-messages
Implementation
Future<bool> verifyStream({
required Stream<Uint8List> messages,
required Uint8List signature,
required Uint8List publicKey,
});